==> mautrix-0.5.4.tar.gz: mautrix-0.5.4/mautrix/types.py <==
# Copyright (c) 2020 Tulir Asokan
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
from .api.http import JSON, Method, APIPath

from .client.api.types import (
    UserID, EventID, RoomID, RoomAlias, FilterID, ContentURI, SyncToken,

    Filter, EventFilter, RoomFilter, RoomEventFilter, StateFilter,

    EventType, RedactionEvent, RedactionEventContent, ReactionEventContent, ReactionEvent,
    MessageEvent, MessageEventContent, MessageUnsigned, MediaMessageEventContent, EncryptedFile,
    LocationMessageEventContent, LocationInfo, RelationType, MessageType, Format, MediaInfo,
    FileInfo, AudioInfo, VideoInfo, ImageInfo, ThumbnailInfo, TextMessageEventContent, JSONWebKey,
    BaseMessageEventContent, RelatesTo, PowerLevelStateEventContent, Membership,
    MemberStateEventContent, StateEvent, AliasesStateEventContent, CanonicalAliasStateEventContent,
    StrippedStateEvent, RoomNameStateEventContent, RoomTopicStateEventContent,
    RoomPinnedEventsStateEventContent, StateUnsigned, RoomAvatarStateEventContent,
    StateEventContent, AccountDataEvent, AccountDataEventContent, RoomTagInfo,
    RoomTagAccountDataEventContent, Event, EventContent, BaseFileInfo, PresenceEventContent,
    PresenceState, TypingEventContent, TypingEvent, PresenceEvent, PresenceState,
    SingleReceiptEventContent, ReceiptEventContent, ReceiptEvent, ReceiptType, GenericEvent,
    Obj, Lst, RoomTombstoneEventContent, EncryptedEvent, EncryptedEventContent, EncryptionAlgorithm,

    RoomCreatePreset, RoomDirectoryVisibility, PaginationDirection, RoomAliasInfo,
    RoomDirectoryResponse, DirectoryPaginationToken, PaginatedMessages,

    User, Member, UserSearchResults,

    MediaRepoConfig, MXOpenGraph, OpenGraphVideo, OpenGraphImage, OpenGraphAudio,

    SerializerError, Serializable, SerializableEnum, SerializableAttrs, serializer, deserializer)

==> mautrix-0.6.0b6.tar.gz: mautrix-0.6.0b6/mautrix/types.py <==
# Copyright (c) 2020 Tulir Asokan
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
from .api.http import JSON, Method, APIPath

from .client.api.types import (
    UserID, DeviceID, EventID, RoomID, RoomAlias, FilterID, ContentURI, SyncToken, SessionID,
    SigningKey, IdentityKey,

    Filter, EventFilter, RoomFilter, RoomEventFilter, StateFilter,

    EventType, RedactionEvent, RedactionEventContent, ReactionEventContent, ReactionEvent,
    MessageEvent, MessageEventContent, MessageUnsigned, MediaMessageEventContent, EncryptedFile,
    LocationMessageEventContent, LocationInfo, RelationType, MessageType, Format, MediaInfo,
    FileInfo, AudioInfo, VideoInfo, ImageInfo, ThumbnailInfo, TextMessageEventContent, JSONWebKey,
    BaseMessageEventContent, RelatesTo, PowerLevelStateEventContent, Membership,
    MemberStateEventContent, StateEvent, AliasesStateEventContent, CanonicalAliasStateEventContent,
    StrippedStateEvent, RoomNameStateEventContent, RoomTopicStateEventContent,
    RoomPinnedEventsStateEventContent, StateUnsigned, RoomAvatarStateEventContent,
    StateEventContent, AccountDataEvent, AccountDataEventContent, RoomTagInfo,
    RoomTagAccountDataEventContent, Event, EventContent, BaseFileInfo, PresenceEventContent,
    PresenceState, TypingEventContent, TypingEvent, PresenceEvent, PresenceState,
    SingleReceiptEventContent, ReceiptEventContent, ReceiptEvent, ReceiptType, GenericEvent,
    Obj, Lst, RoomTombstoneEventContent, EncryptedEvent, EncryptedEventContent, EncryptionAlgorithm,
    EncryptedOlmEventContent, EncryptedMegolmEventContent, ToDeviceEvent, ToDeviceEventContent,
    EncryptionKeyAlgorithm, OlmMsgType, OlmCiphertext, RoomKeyWithheldCode,
    RoomKeyWithheldEventContent, RoomKeyEventContent,

    RoomCreatePreset, RoomDirectoryVisibility, PaginationDirection, RoomAliasInfo,
    RoomDirectoryResponse, DirectoryPaginationToken, PaginatedMessages,

    User, Member, UserSearchResults,

    LoginType, UserIdentifierType, MatrixUserIdentifier, ThirdPartyIdentifier, PhoneIdentifier,
    UserIdentifier, LoginResponse, DiscoveryInformation, DiscoveryServer, DiscoveryIntegrations,
    DiscoveryIntegrationServer, LoginFlow,

    UnsignedDeviceInfo, DeviceKeys, ClaimKeysResponse, QueryKeysResponse,

    MediaRepoConfig, MXOpenGraph, OpenGraphVideo, OpenGraphImage, OpenGraphAudio,

    SerializerError, Serializable, SerializableEnum, SerializableAttrs, serializer, deserializer)
